#
# spec file for package spirv-headers
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           spirv-headers
Version:        1.5.1.corrected+git24
Release:        lp151.3.3.1
Summary:        Machine-readable files from the SPIR-V registry
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/KhronosGroup/SPIRV-Headers

#Source:         https://github.com/KhronosGroup/SPIRV-Headers/archive/%version.tar.gz
Source:         SPIRV-Headers-%version.tar.xz
BuildArch:      noarch
BuildRequires:  cmake >= 2.8
BuildRequires:  fdupes
BuildRequires:  gcc-c++

%description
This repository contains machine-readable files from the SPIR-V
registry. This includes:

* Header files for various languages.
* JSON files describing the grammar for the SPIR-V core instruction
  set, and for the GLSL.std.450 extended instruction set.
* The XML registry file.

%prep 
%autosetup -n SPIRV-Headers-%version

%build
# Because Khronos does not know what DESTDIR is.
%cmake -DCMAKE_INSTALL_PREFIX="%buildroot/%_prefix"
make %{?_smp_mflags}

%install
pushd build/
make install-headers
popd
%fdupes %buildroot/%_prefix

%files
%_includedir/spirv/
%license LICENSE

%changelog
* Wed Apr  8 2020 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 1.5.1.c+git24 (f8bf11a)
  * Add grammars, C header, and header generator for vendor and
    KHR extended instruction sets.
  * Update headers for SPV_KHR_ray_tracing.
  * Added ray flags, primitive culling flags, queries.
  * Add shadercalls scope.
* Sat Oct 26 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.5.1.corrected
  * Add SPV_KHR_physical_storage_buffer.
* Sat Sep 28 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.5.1
  * No change from last snapshot, just a version bump.
* Wed Aug 21 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new snapshot 1.4.1.g36
  * Add INTEL_shader_integer_functions2,
    SPV_EXT_fragment_shader_interlock,
    SPV_EXT_demote_to_helper_invocation.
  * Add support for SPV_NV_sm_shader_builtins.
  * Add Volatile to Memory Semantics, for
    SPV_KHR_vulkan_memory_model.
  * Add SPV_KHR_shader_clock to spirv-headers.
* Tue Jun  4 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new snapshot 1.4.1.g17
  * Add INTEL_shader_integer_functions2 and
    SPV_EXT_fragment_shader_interlock.
  * Enable Groups capability by the extension SPV_AMD_shader_ballot.
  * Add support for SPV_NV_sm_shader_builtins.
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.3.7
  * Synchronize to revision 7 of the header specification
    from Khronos.
* Mon Jan  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new snapshot 1.3.g60
  * Support for SPV_EXT_physical_storage_buffer
* Fri Dec 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new snapshot 1.3.g50
  * Reserve tokens for float controls and no integer wrapping
  * Add JSON support for SPV_EXT_fragment_invocation_density
* Sat Nov 10 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new snapshot 1.3.g44
  * Add enumerants for six Nvidia extensions
  * Add support for nv-raytracing
* Fri Aug 24 2018 jengelh@inai.de
- Update to new snapshot 1.3.g34
  * Add missing extension/capability requirements for some symbols
  * Add SPV_NV_shader_subgroup_partitioned to SPIR-V JSON.
  * Add missing 'extensions' for OpGroupNonUniformPartitionNV.
  * Add tokens for SPV_EXT_descriptor_indexing.
  * SPV_GOOGLE_hlsl_functionality1 includes all of
    SPV_GOOGLE_decorate_string.
  * Clay Shader Compiler
  * Add enumerants for SPV_KHR_8bit_storage.
* Thu Mar  8 2018 jengelh@inai.de
- Update to new snapshot 1.3.g0
  * Allow SubgroupSize and SubgroupLocalInvocationId with SubgroupBallotKHR
  * Add headers for the 1.2 unified (1.0, 1.1, and 1.2) specification.
  * 464d17b Refresh 1.3 headers from spec repo
* Wed Feb  7 2018 jengelh@inai.de
- Update to new snapshot 1.2.g22
  * Add headers for the 1.2 unified (1.0, 1.1, and 1.2)
    specification.
* Fri Nov 17 2017 jengelh@inai.de
- Update to new snapshot 1.2.g13
  * Add new Intel token reservations, new tokens for
    SPV_AMD_shader_fragment_mask, and new tokens for
    SPV_AMD_shader_fragment_mask.
  * Update all headers for SPV_EXT_shader_stencil_export.
  * Add SPV_EXT_shader_viewport_index_layer.
* Mon Aug  7 2017 jengelh@inai.de
- Update to new snapshot 1.1.g46
  * Reserve number 16 for the Mesa-IR/SPIR-V Translator.
* Tue Jul 18 2017 jengelh@inai.de
- Update to new snapshot 1.1.g44
  * reserve SPIR-V enum block for upcoming Intel extension
  * Add version 1.2 headers, update 1.1 headers to revision 7,
    update 1.0 headers to revision 11.
  * Synchronize OpenCL extended instruction set header with spec,
    and add missing capability use to the JSON grammar.
  * Update JSON grammar files for 16-bit storage.
* Mon Feb 20 2017 jengelh@inai.de
- Update to new snapshot 1.1.g31
  * New revisions of SPIR-V 1.0 and 1.1, and both extended
    instruction sets.
* Thu Feb  2 2017 jengelh@inai.de
- Update to new snapshot 1.1.g29
  * Add "Shaderc over Glslang" as a front end.
  * Update to Rev. 8 of 1.0 and Rev. 4 of 1.1. Includes enums for
    SPV_KHR_shader_draw_parameters.
  * Add SPV_KHR_shader_ballot enumerants.
* Sun Jun 12 2016 jengelh@inai.de
- Initial package (version 1.1.g15) for build.opensuse.org
